@@ -10,6 +10,7 @@
 #include "dolphin_generalsettings.h"
 #include "dolphinviewcontainer.h"
 
+#include <QFrame>
 #include <QGridLayout>
 #include <QStyle>
 #include <QVariantAnimation>
@@ -24,6 +25,7 @@ void resetSplitterSizes(QSplitter *splitter)
 
 DolphinTabPage::DolphinTabPage(const QUrl &primaryUrl, const QUrl &secondaryUrl, QWidget *parent)
     : QWidget(parent)
+    , m_splitterLastPosition(0)
     , m_expandingContainer{nullptr}
     , m_primaryViewActive(true)
     , m_splitViewEnabled(false)
@@ -71,6 +73,11 @@ bool DolphinTabPage::splitViewEnabled() const
     return m_splitViewEnabled;
 }
 
+void DolphinTabPage::splitterMoved(int pos)
+{
+    m_splitterLastPosition = pos;
+}
+
 void DolphinTabPage::setSplitViewEnabled(bool enabled, Animated animated, const QUrl &secondaryUrl)
 {
     if (m_splitViewEnabled == enabled) {
@@ -220,6 +227,7 @@ void DolphinTabPage::connectNavigators(DolphinNavigatorsWidgetAction *navigators
 void DolphinTabPage::disconnectNavigators()
 {
     m_navigatorsWidget = nullptr;
+    m_navigatorSeparator = nullptr;
     m_primaryViewContainer->disconnectUrlNavigator();
     if (m_splitViewEnabled) {
         m_secondaryViewContainer->disconnectUrlNavigator();
@@ -230,12 +238,23 @@ void DolphinTabPage::insertNavigatorsWidget(DolphinNavigatorsWidgetAction *navig
 {
     QGridLayout *gridLayout = static_cast<QGridLayout *>(layout());
     if (navigatorsWidget->isInToolbar()) {
+        if (m_navigatorSeparator) {
+            m_navigatorSeparator->setFrameStyle(QFrame::NoFrame);
+            gridLayout->removeWidget(m_navigatorSeparator.get());
+        }
         gridLayout->setRowMinimumHeight(0, 0);
     } else {
         // We set a row minimum height, so the height does not visibly change whenever
         // navigatorsWidget is inserted which happens every time the current tab is changed.
         gridLayout->setRowMinimumHeight(0, navigatorsWidget->primaryUrlNavigator()->height());
         gridLayout->addWidget(navigatorsWidget->requestWidget(this), 0, 0);
+        if (!m_navigatorSeparator) {
+            m_navigatorSeparator = std::make_unique<QFrame>(this);
+        }
+        m_navigatorSeparator->setFrameStyle(QFrame::HLine);
+        m_navigatorSeparator->setFixedHeight(1);
+        m_navigatorSeparator->setContentsMargins(0, 0, 0, 0);
+        gridLayout->addWidget(m_navigatorSeparator.get(), 1, 0, 0, -1);
     }
 }
 
@@ -268,7 +287,7 @@ QByteArray DolphinTabPage::saveState() const
     QByteArray state;
     QDataStream stream(&state, QIODevice::WriteOnly);
 
-    stream << quint32(2); // Tab state version
+    stream << quint32(3); // Tab state version
 
     stream << m_splitViewEnabled;
 
@@ -284,6 +303,7 @@ QByteArray DolphinTabPage::saveState() const
 
     stream << m_primaryViewActive;
     stream << m_splitter->saveState();
+    stream << m_splitterLastPosition;
 
     if (!m_customLabel.isEmpty()) {
         stream << m_customLabel;
@@ -304,7 +324,7 @@ void DolphinTabPage::restoreState(const QByteArray &state)
     // Read the version number of the tab state and check if the version is supported.
     quint32 version = 0;
     stream >> version;
-    if (version != 2) {
+    if (version != 3) {
         // The version of the tab state isn't supported, we can't restore it.
         return;
     }
@@ -342,6 +362,7 @@ void DolphinTabPage::restoreState(const QByteArray &state)
     QByteArray splitterState;
     stream >> splitterState;
     m_splitter->restoreState(splitterState);
+    stream >> m_splitterLastPosition;
 
     if (!stream.atEnd()) {
         QString tabTitle;
@@ -467,17 +488,7 @@ void DolphinTabPage::slotViewActivated()
 
 void DolphinTabPage::slotViewUrlRedirection(const QUrl &oldUrl, const QUrl &newUrl)
 {
-    // Make sure the url of the view is updated. BUG:496414
-    if (splitViewEnabled()) {
-        if (primaryViewContainer()->view()->url() == oldUrl) {
-            primaryViewContainer()->view()->setUrl(newUrl);
-        }
-        if (secondaryViewContainer()->view()->url() == oldUrl) {
-            secondaryViewContainer()->view()->setUrl(newUrl);
-        }
-    } else {
-        activeViewContainer()->view()->setUrl(newUrl);
-    }
+    Q_UNUSED(oldUrl)
     Q_EMIT activeViewUrlChanged(newUrl);
 }
 
@@ -522,7 +533,7 @@ void DolphinTabPage::startExpandViewAnimation(DolphinViewContainer *expandingCon
 
     m_expandViewAnimation->setStartValue(expandingContainer->width());
     if (m_splitViewEnabled) { // A new viewContainer is being opened.
-        m_expandViewAnimation->setEndValue(m_splitter->width() / 2);
+        m_expandViewAnimation->setEndValue(m_splitterLastPosition ? (m_splitter->width() - m_splitterLastPosition) : (m_splitter->width() / 2));
         m_expandViewAnimation->setEasingCurve(QEasingCurve::OutCubic);
     } else { // A viewContainer is being closed.
         m_expandViewAnimation->setEndValue(m_splitter->width());
