@@ -155,9 +155,13 @@ public:
 Q_SIGNALS:
     void activeViewChanged(DolphinViewContainer *viewContainer);
     void activeViewUrlChanged(const QUrl &url);
-    void splitterMoved(int pos, int index);
 
 private Q_SLOTS:
+    /**
+     * Saves splitter position to be able to restore it on split mode OFF->ON
+     */
+    void splitterMoved(int pos);
+
     /**
      * Deletes all zombie viewContainers that were used for the animation
      * and resets the minimum size of the others to a sane value.
@@ -210,11 +214,14 @@ private:
     DolphinViewContainer *m_expandingContainer;
     QPointer<QVariantAnimation> m_expandViewAnimation;
 
+    std::unique_ptr<QFrame> m_navigatorSeparator;
+
     bool m_primaryViewActive;
     bool m_splitViewEnabled;
     bool m_active;
     /** @see setCustomLabel(). */
     QString m_customLabel;
+    int m_splitterLastPosition = 0;
 };
 
 class DolphinTabPageSplitterHandle : public QSplitterHandle
