@@ -27,9 +27,9 @@
 #include <KFileItemActions>
 #include <KFilePlacesModel>
 #include <KIO/JobUiDelegateFactory>
+#include <KIO/MkpathJob>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
-#include <KMessageWidget>
 #include <KProtocolManager>
 #include <KShell>
 #include <kio_version.h>
@@ -76,6 +76,7 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     , m_searchModeEnabled(false)
     , m_adminBar{nullptr}
     , m_authorizeToEnterFolderAction{nullptr}
+    , m_createFolderAction(nullptr)
     , m_messageWidget(nullptr)
     , m_selectionModeTopBar{nullptr}
     , m_view(nullptr)
@@ -776,13 +777,17 @@ void DolphinViewContainer::slotItemActivated(const KFileItem &item)
 void DolphinViewContainer::slotfileMiddleClickActivated(const KFileItem &item)
 {
     KService::List services = KApplicationTrader::queryByMimeType(item.mimetype());
+    const auto modifiers = QGuiApplication::keyboardModifiers();
 
     int indexOfAppToOpenFileWith = 1;
+    if (modifiers & Qt::ShiftModifier) {
+        indexOfAppToOpenFileWith = 2;
+    }
 
     // executable scripts
     auto mimeType = item.currentMimeType();
     if (item.isLocalFile() && mimeType.inherits(QStringLiteral("application/x-executable")) && mimeType.inherits(QStringLiteral("text/plain"))
-        && QFileInfo(item.localPath()).isExecutable()) {
+        && item.isExecutable()) {
         KConfigGroup cfgGroup(KSharedConfig::openConfig(QStringLiteral("kiorc")), QStringLiteral("Executable scripts"));
         const QString value = cfgGroup.readEntry("behaviourOnLaunch", "alwaysAsk");
 
@@ -802,9 +807,8 @@ void DolphinViewContainer::slotfileMiddleClickActivated(const KFileItem &item)
         connect(job, &KIO::OpenUrlJob::finished, this, &DolphinViewContainer::slotOpenUrlFinished);
         job->start();
     } else {
-        // If no 2nd service available, try to open archives in new tabs, regardless of the "Open archives as folder" setting.
+        // If no 2nd or 3rd service available, try to open archives in new tabs, regardless of the "Browse compressed files as folders" setting.
         const QUrl &url = DolphinView::openItemAsFolderUrl(item);
-        const auto modifiers = QGuiApplication::keyboardModifiers();
         if (!url.isEmpty()) {
             // keep in sync with KUrlNavigator::slotNavigatorButtonClicked
             if (modifiers & Qt::ShiftModifier) {
@@ -937,6 +941,21 @@ void DolphinViewContainer::redirect(const QUrl &oldUrl, const QUrl &newUrl)
     setSearchBarVisible(isSearchUrl(newUrl));
 
     m_urlNavigator->blockSignals(block);
+
+    // Before emitting `urlChanged`, temporarily disconnect the `activated` signal to avoid activation of `DolphinViewContainer`.
+    bool blockActivation = m_urlNavigatorConnected && !isActive();
+    if (blockActivation) {
+        disconnect(m_urlNavigatorConnected, &DolphinUrlNavigator::activated, this, &DolphinViewContainer::activate);
+    }
+
+    Q_EMIT m_view->urlChanged(newUrl);
+
+    if (blockActivation) {
+        connect(m_urlNavigatorConnected, &DolphinUrlNavigator::activated, this, &DolphinViewContainer::activate);
+
+        // Force inactivate `DolphinUrlNavigator`.
+        m_urlNavigatorConnected->setActive(false);
+    }
 }
 
 void DolphinViewContainer::requestFocus()
@@ -955,6 +974,22 @@ void DolphinViewContainer::slotStatusBarZoomLevelChanged(int zoomLevel)
     m_view->setZoomLevel(zoomLevel);
 }
 
+bool DolphinViewContainer::isTopMostParentFolderWritable(QUrl url)
+{
+    Q_ASSERT(url.isLocalFile());
+    while (url.isValid()) {
+        url = url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
+        QFileInfo info(url.toLocalFile());
+        if (info.exists()) {
+            return info.isWritable();
+        }
+        if (info.isSymLink()) {
+            return false;
+        }
+    }
+    return false;
+}
+
 void DolphinViewContainer::slotErrorMessageFromView(const QString &message, const int kioErrorCode)
 {
     if (kioErrorCode == KIO::ERR_CANNOT_ENTER_DIRECTORY && m_view->url().scheme() == QStringLiteral("file")
@@ -973,6 +1008,33 @@ void DolphinViewContainer::slotErrorMessageFromView(const QString &message, cons
         }
         showMessage(i18nc("@info", "Authorization required to enter this folder."), KMessageWidget::Error, {m_authorizeToEnterFolderAction});
         return;
+    } else if (kioErrorCode == KIO::ERR_DOES_NOT_EXIST && m_view->url().isLocalFile()) {
+        if (!m_createFolderAction) {
+            m_createFolderAction = new QAction(this);
+            m_createFolderAction->setText(i18nc("@action", "Create missing folder"));
+            m_createFolderAction->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
+            connect(m_createFolderAction, &QAction::triggered, this, [this](bool) {
+                KIO::MkpathJob *job = KIO::mkpath(m_view->url());
+                KIO::FileUndoManager::self()->recordJob(KIO::FileUndoManager::Mkpath, {}, m_view->url(), job);
+                connect(job, &KJob::result, this, [this](KJob *job) {
+                    if (job->error()) {
+                        showErrorMessage(job->errorString());
+                    } else {
+                        m_view->reload();
+                        m_messageWidget->animatedHide();
+                    }
+                });
+            });
+        }
+        if (isTopMostParentFolderWritable(m_view->url())) {
+            m_createFolderAction->setEnabled(true);
+            m_createFolderAction->setToolTip(i18nc("@info:tooltip", "Create the folder at this path and open it"));
+        } else {
+            m_createFolderAction->setEnabled(false);
+            m_createFolderAction->setToolTip(i18nc("@info:tooltip", "You do not have permission to create the folder"));
+        }
+        showMessage(message, KMessageWidget::Error, {m_createFolderAction});
+        return;
     }
     Q_EMIT showErrorMessage(message);
 }
