@@ -13,6 +13,7 @@
 #include <QPointer>
 #include <QUrl>
 #include <QWidget>
+#include <QTextEdit>
 
 class KFileItemList;
 class MediaWidget;
@@ -146,13 +147,14 @@ private:
 
     PixmapViewer *m_preview;
     MediaWidget *m_mediaWidget;
-    QLabel *m_nameLabel;
+    QTextEdit *m_nameLabel;
     Baloo::FileMetaDataWidget *m_metaDataWidget;
     QScrollArea *m_metaDataArea;
     QLabel *m_configureLabel;
     QDialogButtonBox *m_configureButtons;
 
     bool m_isVideo;
+    QUrl m_disabledPreviewUrl;
 };
 
 #endif // INFORMATIONPANELCONTENT_H
