@@ -19,7 +19,7 @@ class DolphinViewModesConfigModule : public KCModule
     Q_OBJECT
 
 public:
-    DolphinViewModesConfigModule(QWidget *parent, const QVariantList &args);
+    DolphinViewModesConfigModule(QObject *parent, const KPluginMetaData &data);
     ~DolphinViewModesConfigModule() override;
 
     void save() override;
