@@ -5,8 +5,6 @@
  */
 
 #include "contentdisplaytab.h"
-#include "dolphin_contentdisplaysettings.h"
-#include "dolphin_generalsettings.h"
 
 #include <KFormat>
 #include <KLocalizedString>
@@ -168,6 +166,8 @@ void ContentDisplayTab::applySettings()
         settings->setElidingMode(ContentDisplaySettings::ElidingMode::Right);
     }
     settings->save();
+
+    GeneralSettings::self()->save();
 }
 
 void ContentDisplayTab::loadSettings()
