@@ -68,6 +68,7 @@ private Q_SLOTS:
     void testInlineRename();
     void testThumbnailAfterRename();
     void testViewModeAfterDynamicView();
+    void testActivationAndTabTitleAfterRenameOpeningFolder();
     void cleanupTestCase();
 
 private:
@@ -82,6 +83,9 @@ void DolphinMainWindowTest::initTestCase()
     settings->setShowStatusBar(GeneralSettings::EnumShowStatusBar::FullWidth);
     settings->setShowZoomSlider(true);
     settings->save();
+
+    // to save us from kxmlgui / KLocalized warning
+    KLocalizedString::setApplicationDomain({"dolphin"});
 }
 
 void DolphinMainWindowTest::init()
@@ -101,13 +105,13 @@ void DolphinMainWindowTest::testSyncDesktopAndPhoneUi()
 
     QDomDocument desktopUi;
     QFile desktopUiXmlFile(":/kxmlgui5/dolphin/dolphinui.rc");
-    desktopUiXmlFile.open(QIODevice::ReadOnly);
+    QVERIFY2(desktopUiXmlFile.open(QIODevice::ReadOnly), qPrintable(QStringLiteral("couldn't open %1").arg(desktopUiXmlFile.fileName())));
     desktopUi.setContent(&desktopUiXmlFile);
     desktopUiXmlFile.close();
 
     QDomDocument phoneUi;
     QFile phoneUiXmlFile(":/kxmlgui5/dolphin/dolphinuiforphones.rc");
-    phoneUiXmlFile.open(QIODevice::ReadOnly);
+    QVERIFY2(phoneUiXmlFile.open(QIODevice::ReadOnly), qPrintable(QStringLiteral("couldn't open %1").arg(phoneUiXmlFile.fileName())));
     phoneUi.setContent(&phoneUiXmlFile);
     phoneUiXmlFile.close();
 
@@ -421,7 +425,7 @@ void DolphinMainWindowTest::testCreateFileAction()
     QCOMPARE(file.size(), 0);
 }
 
- void DolphinMainWindowTest::testCreateFileActionRequiresWritePermission()
+void DolphinMainWindowTest::testCreateFileActionRequiresWritePermission()
 {
     QScopedPointer<TestDir> testDir{new TestDir()};
     QString testDirUrl(QDir::cleanPath(testDir->url().toString()));
@@ -435,6 +439,8 @@ void DolphinMainWindowTest::testCreateFileAction()
     QVERIFY(QTest::qWaitForWindowExposed(m_mainWindow.data()));
     QVERIFY(m_mainWindow->isVisible());
 
+    QTRY_VERIFY_WITH_TIMEOUT(QApplication::activeWindow() != nullptr, 100);
+
     QCOMPARE(m_mainWindow->m_activeViewContainer->view()->items().count(), 0);
 
     auto createFileAction = m_mainWindow->actionCollection()->action(QStringLiteral("create_file"));
@@ -482,6 +488,7 @@ void DolphinMainWindowTest::testFocusLocationBar()
     m_mainWindow->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_mainWindow.data()));
     QVERIFY(m_mainWindow->isVisible());
+    QTRY_VERIFY_WITH_TIMEOUT(QApplication::activeWindow() != nullptr, 100);
 
     QAction *replaceLocationAction = m_mainWindow->actionCollection()->action(QStringLiteral("replace_location"));
     replaceLocationAction->trigger();
@@ -511,6 +518,7 @@ void DolphinMainWindowTest::testFocusPlacesPanel()
     m_mainWindow->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_mainWindow.data()));
     QVERIFY(m_mainWindow->isVisible());
+    QTRY_VERIFY_WITH_TIMEOUT(QApplication::activeWindow() != nullptr, 100);
 
     QWidget *placesPanel = reinterpret_cast<QWidget *>(m_mainWindow->m_placesPanel);
     QVERIFY2(QTest::qWaitFor(
@@ -852,6 +860,7 @@ void DolphinMainWindowTest::testAccessibilityTree()
     m_mainWindow->show();
     QVERIFY(QTest::qWaitForWindowExposed(m_mainWindow.data()));
     QVERIFY(m_mainWindow->isVisible());
+    QTRY_VERIFY_WITH_TIMEOUT(QApplication::activeWindow() != nullptr, 100);
 
     QAccessibleInterface *accessibleInterfaceOfMainWindow = QAccessible::queryAccessibleInterface(m_mainWindow.get());
     Q_CHECK_PTR(accessibleInterfaceOfMainWindow);
@@ -1101,15 +1110,15 @@ void DolphinMainWindowTest::testViewModeAfterDynamicView()
     m_mainWindow->openFiles({testDirUrl + "/a"}, false);
     view->m_model->loadDirectory(QUrl(testDirUrl + "/a"));
     view->setUrl(QUrl(testDirUrl + "/a"));
-    QVERIFY(modelDirectoryLoadingCompletedSpy.wait());
-    QCOMPARE(view->m_mode, DolphinView::IconsView);
+    QVERIFY(viewDirectoryLoadingCompletedSpy.wait());
+    QTRY_COMPARE_WITH_TIMEOUT(view->m_mode, DolphinView::IconsView, 200);
 
     // go back to parent folder and check that view mode reverted to details
     m_mainWindow->actionCollection()->action(KStandardAction::name(KStandardAction::Back))->trigger();
     view->m_model->loadDirectory(testDir->url());
     view->setUrl(testDir->url());
-    QVERIFY(modelDirectoryLoadingCompletedSpy.wait());
-    QCOMPARE(view->m_mode, DolphinView::DetailsView);
+    QVERIFY(viewDirectoryLoadingCompletedSpy.wait());
+    QTRY_COMPARE_WITH_TIMEOUT(view->m_mode, DolphinView::DetailsView, 200);
 
     // test for local views
     settings->setGlobalViewProps(false);
@@ -1119,10 +1128,9 @@ void DolphinMainWindowTest::testViewModeAfterDynamicView()
     m_mainWindow->openFiles({testDirUrl + "/a"}, false);
     view->m_model->loadDirectory(QUrl(testDirUrl + "/a"));
     view->setUrl(QUrl(testDirUrl + "/a"));
-    QVERIFY(modelDirectoryLoadingCompletedSpy.wait());
-    QCOMPARE(view->m_mode, DolphinView::IconsView);
-    QTest::qWait(100);
-    QVERIFY(ViewProperties(view->viewPropertiesUrl()).dynamicViewPassed());
+    QVERIFY(viewDirectoryLoadingCompletedSpy.wait());
+    QTRY_COMPARE_WITH_TIMEOUT(view->m_mode, DolphinView::IconsView, 100);
+    QTRY_VERIFY_WITH_TIMEOUT(ViewProperties(view->viewPropertiesUrl()).dynamicViewPassed(), 200);
 
     // change view mode of child folder to "Details"
     m_mainWindow->actionCollection()->action(QStringLiteral("details"))->trigger();
@@ -1145,6 +1153,85 @@ void DolphinMainWindowTest::testViewModeAfterDynamicView()
     QVERIFY(ViewProperties(view->viewPropertiesUrl()).dynamicViewPassed());
 }
 
+void DolphinMainWindowTest::testActivationAndTabTitleAfterRenameOpeningFolder()
+{
+    QScopedPointer<TestDir> testDir{new TestDir()};
+    testDir->createDir("a");
+    const QUrl parentDirUrl = QUrl::fromLocalFile(testDir->url().toLocalFile());
+    const QUrl childDirUrl = QUrl::fromLocalFile(testDir->url().toLocalFile() + "/a");
+
+    auto tabWidget = m_mainWindow->findChild<DolphinTabWidget *>("tabWidget");
+    QVERIFY(tabWidget);
+
+    // Tab 0: Open childDirUrl
+    m_mainWindow->openDirectories({childDirUrl}, false);
+    m_mainWindow->show();
+    QVERIFY(QTest::qWaitForWindowExposed(m_mainWindow.data()));
+    QVERIFY(m_mainWindow->isVisible());
+
+    // Tab 0: Enable split view
+    m_mainWindow->actionCollection()->action(QStringLiteral("split_view"))->setChecked(true);
+    m_mainWindow->actionCollection()->action(QStringLiteral("split_view"))->trigger();
+    QVERIFY(tabWidget->currentTabPage()->splitViewEnabled());
+
+    // Tab 1: Open childDirUrl
+    tabWidget->openNewActivatedTab(childDirUrl);
+
+    // Tab 1: Open parentDirUrl in right view
+    m_mainWindow->actionCollection()->action(QStringLiteral("split_view"))->setChecked(true);
+    m_mainWindow->actionCollection()->action(QStringLiteral("split_view"))->trigger();
+    QVERIFY(tabWidget->currentTabPage()->splitViewEnabled());
+
+    DolphinView *view = m_mainWindow->activeViewContainer()->view();
+    view->m_model->loadDirectory(parentDirUrl);
+    view->setUrl(parentDirUrl);
+
+    // Check current view is right view
+    QVERIFY(tabWidget->currentTabPage()->secondaryViewContainer()->isActive());
+
+    // Check all tab titles are correct
+    // Tab 0: (a) | a
+    // Tab 1: (a) | parentDir
+    const QString parentDirName = QFileInfo(parentDirUrl.toString()).fileName();
+    const QString childDirName = QFileInfo(childDirUrl.toString()).fileName();
+    const QString expectedTab0Title = QStringLiteral("(%1) | %2").arg(childDirName, childDirName);
+    const QString expectedTab1Title = QStringLiteral("(%1) | %2").arg(childDirName, parentDirName);
+    QCOMPARE(tabWidget->tabText(0), expectedTab0Title);
+    QCOMPARE(tabWidget->tabText(1), expectedTab1Title);
+
+    // Prepare signal spies
+    QSignalSpy viewDirectoryLoadingCompletedSpy(view, &DolphinView::directoryLoadingCompleted);
+    QSignalSpy itemsChangedSpy(view->m_model, &KFileItemModel::itemsChanged);
+
+    QVERIFY(viewDirectoryLoadingCompletedSpy.wait());
+
+    // Rename child dir to "b"
+    view->markUrlsAsSelected({childDirUrl});
+    view->updateViewState();
+    view->renameSelectedItems(); // Rename inline
+
+    QTest::keyClick(QApplication::focusWidget(), Qt::Key_B);
+    QTest::keyClick(QApplication::focusWidget(), Qt::Key_Enter);
+    QVERIFY(itemsChangedSpy.wait()); // Make sure that rename worked
+    QVERIFY(viewDirectoryLoadingCompletedSpy.wait()); // and the directory has finished loading
+
+    // Check current view is right view
+    QVERIFY(tabWidget->currentTabPage()->secondaryViewContainer()->isActive());
+
+    // Check navigator in left view is inactive
+    auto leftViewNavigator = tabWidget->currentTabPage()->primaryViewContainer()->urlNavigator();
+    QVERIFY(!leftViewNavigator->isActive());
+
+    // Check all tab titles are correct after rename
+    // Tab 0: (b) | b
+    // Tab 1: (b) | parentDir
+    const QString newChildDirName = QStringLiteral("b");
+    const QString expectedNewTab0Title = QStringLiteral("(%1) | %2").arg(newChildDirName, newChildDirName);
+    const QString expectedNewTab1Title = QStringLiteral("(%1) | %2").arg(newChildDirName, parentDirName);
+    QCOMPARE(tabWidget->tabText(0), expectedNewTab0Title);
+    QCOMPARE(tabWidget->tabText(1), expectedNewTab1Title);
+}
+
 void DolphinMainWindowTest::cleanupTestCase()
 {
     m_mainWindow->showNormal();
